#
# spec file for package perl-Email-Sender
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Email-Sender
Name:           perl-Email-Sender
Version:        2.601.0
Release:        1.5
# 2.601 -> normalize -> 2.601.0
%define cpan_version 2.601
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Library for sending email
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny) >= 0.08
BuildRequires:  perl(Email::Abstract) >= 3.006
BuildRequires:  perl(Email::Address::XS)
BuildRequires:  perl(Email::Simple) >= 1.998
BuildRequires:  perl(ExtUtils::MakeMaker) >= 6.78
BuildRequires:  perl(File::Path) >= 2.06
BuildRequires:  perl(List::Util) >= 1.45
BuildRequires:  perl(Module::Runtime)
BuildRequires:  perl(Moo) >= 2.000000
BuildRequires:  perl(Moo::Role)
BuildRequires:  perl(MooX::Types::MooseLike) >= 0.15
BuildRequires:  perl(MooX::Types::MooseLike::Base)
BuildRequires:  perl(Net::SMTP) >= 3.07
BuildRequires:  perl(Sub::Exporter)
BuildRequires:  perl(Sub::Exporter::Util)
BuildRequires:  perl(Test::More) >= 0.96
BuildRequires:  perl(Throwable::Error) >= 0.200003
BuildRequires:  perl(Try::Tiny)
Requires:       perl(Email::Abstract) >= 3.006
Requires:       perl(Email::Address::XS)
Requires:       perl(Email::Simple) >= 1.998
Requires:       perl(File::Path) >= 2.06
Requires:       perl(List::Util) >= 1.45
Requires:       perl(Module::Runtime)
Requires:       perl(Moo) >= 2.000000
Requires:       perl(Moo::Role)
Requires:       perl(MooX::Types::MooseLike) >= 0.15
Requires:       perl(MooX::Types::MooseLike::Base)
Requires:       perl(Net::SMTP) >= 3.07
Requires:       perl(Sub::Exporter)
Requires:       perl(Sub::Exporter::Util)
Requires:       perl(Throwable::Error) >= 0.200003
Requires:       perl(Try::Tiny)
Provides:       perl(Email::Sender) = %{version}
Provides:       perl(Email::Sender::Failure) = %{version}
Provides:       perl(Email::Sender::Failure::Multi) = %{version}
Provides:       perl(Email::Sender::Failure::Permanent) = %{version}
Provides:       perl(Email::Sender::Failure::Temporary) = %{version}
Provides:       perl(Email::Sender::Manual) = %{version}
Provides:       perl(Email::Sender::Manual::QuickStart) = %{version}
Provides:       perl(Email::Sender::Role::CommonSending) = %{version}
Provides:       perl(Email::Sender::Role::HasMessage) = %{version}
Provides:       perl(Email::Sender::Simple) = %{version}
Provides:       perl(Email::Sender::Success) = %{version}
Provides:       perl(Email::Sender::Success::Partial) = %{version}
Provides:       perl(Email::Sender::Transport) = %{version}
Provides:       perl(Email::Sender::Transport::DevNull) = %{version}
Provides:       perl(Email::Sender::Transport::Failable) = %{version}
Provides:       perl(Email::Sender::Transport::Maildir) = %{version}
Provides:       perl(Email::Sender::Transport::Mbox) = %{version}
Provides:       perl(Email::Sender::Transport::Print) = %{version}
Provides:       perl(Email::Sender::Transport::SMTP) = %{version}
Provides:       perl(Email::Sender::Transport::SMTP::Persistent) = %{version}
Provides:       perl(Email::Sender::Transport::Sendmail) = %{version}
Provides:       perl(Email::Sender::Transport::Test) = %{version}
Provides:       perl(Email::Sender::Transport::Wrapper) = %{version}
Provides:       perl(Email::Sender::Util) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
Email::Sender replaces the old and sometimes problematic Email::Send
library, which did a decent job at handling very simple email sending
tasks, but was not suitable for serious use, for a variety of reasons.

Most users will be able to use Email::Sender::Simple to send mail. Users
with more specific needs should look at the available
Email::Sender::Transport classes.

Documentation may be found in Email::Sender::Manual, and new users should
start with Email::Sender::Manual::QuickStart.

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README util
%license LICENSE

%changelog
* Thu Jan 18 2024 Tina Müller <timueller+perl@suse.de>
- updated to 2.601
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  2.601     2024-01-17 19:15:25-05:00 America/New_York
  - allow using an Authen::SASL instance via sasl_authenticator as an
    alternative to username asd password (thanks, Erik Huelsmann!)
* Mon Oct 24 2022 Tina Müller <timueller+perl@suse.de>
- updated to 2.600
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  2.600     2022-10-23 16:45:34-04:00 America/New_York
  - This version replaces the use of Email::Address with
    Email::Address::XS, as the pure perl version has problems with
    certain kinds of input.
* Mon Jul  5 2021 Tina Müller <timueller+perl@suse.de>
- updated to 2.500
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  2.500     2021-07-04 13:26:47-04:00 America/New_York
  - version bumped to account for change in fractional part precision
* Mon Jun 21 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.500
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.500     2021-06-20 20:30:24-04:00 America/New_York
  - adjust version number for bookkeeping reasons
  1.300036  2021-06-17 09:51:12-04:00 America/New_York
  - add "maybestarttls" option, to allow opportunistic STARTTLS
    (thanks, Marc Bradshaw!)
* Sun Oct 11 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.300035
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300035  2020-10-10 12:34:29-04:00 America/New_York
  - drop some needless version checking from the days when we worked with
    broken Net::SMTPs (thanks, Bernhard Graf and Aristotle Pagaltzis and
    Pali Rohár)
  - documentation tweaks and spelling corrections (thanks, James E
    Keenan, Stefan Hornburg, M Somerville, and jazzkutya)
* Wed Dec  4 2019 <timueller+perl@suse.de>
- updated to 1.300034
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300034  2019-12-02 22:21:58-05:00 America/New_York
  - add documentation for the SMTP "hosts" parameter!
* Wed Nov 27 2019 <timueller+perl@suse.de>
- updated to 1.300033
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300033  2019-11-26 14:44:51-05:00 America/New_York
  - no changes since 1.300031
* Wed Apr  5 2017 coolo@suse.com
- updated to 1.300031
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300031  2017-04-04 14:35:42-04:00 America/New_York
  - EMAIL_SENDER_TRANSPORT did not properly handle the =-prefix case
    Now: =Foo::Bar expands to Foo::Bar, Foo::Bar expands to Foo::Bar,
    and FooBar expands to Email::Sender::Transport::FooBar, as intended.
    Previously, =Foo::Bar expanded to Email::Sender::Transport::Foo::Bar
* Wed Oct  5 2016 coolo@suse.com
- updated to 1.300030
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300030  2016-10-03 18:33:57-04:00 America/New_York
  - no changes since 1.300029
  1.300029  2016-07-17 15:49:18-04:00 America/New_York (TRIAL RELEASE)
  - bring localpart quoting more in line with RFC 821
* Mon May 23 2016 coolo@suse.com
- updated to 1.300028
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300028  2016-04-21 17:49:14+01:00 Europe/London
  - make Email::Sender::Util->easy_transport public
* Tue Apr 12 2016 coolo@suse.com
- updated to 1.300027
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300027  2016-04-03 10:02:52-04:00 America/New_York
  - no changes since 1.300026
  - SMTP transport now uses Net::SMTP for SSL and STARTTLS support
  1.300026  2016-03-21 13:50:22-04:00 America/New_York (TRIAL RELEASE)
  - another tweak to Net::SMTP and Test::MockObject, thanks to Matthew
    Horsfall
  1.300025  2016-03-19 17:11:34-04:00 America/New_York (TRIAL RELEASE)
  - tweak how we load Net::SMTP to avoid problems when testing with a
    Test::MockObject-mocked SMTP client
  1.300024  2016-03-19 14:13:16-04:00 America/New_York (TRIAL RELEASE)
  - Net::SMTP 3.07 is now required, both for SSL support and for a fix
    to datasend implementation referenced in 1.300019 changes
  1.300023  2016-03-19 14:06:51-04:00 America/New_York (TRIAL RELEASE)
  - Email::Sender::Transport::SMTP now uses Net::SMTP for SSL
    connections, and for a STARTTLS implementation
* Fri Oct 16 2015 coolo@suse.com
- updated to 1.300021
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300021  2015-10-15 13:53:52-04:00 America/New_York
  - when SMTP connection fails, include host and port in error
* Fri Sep  4 2015 coolo@suse.com
- updated to 1.300020
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300020  2015-09-03 14:00:04-04:00 America/New_York
  - no changes since 1.300019
  1.300019  2015-08-10 15:48:02-04:00 America/New_York (TRIAL RELEASE)
  - only work around Net::SMTP on broken (pre-3.07) versions
  - avoid uninitialized warning when delivering to Maildir
* Sun Jun  7 2015 coolo@suse.com
- updated to 1.300018
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300018  2015-05-27 15:28:44-04:00 America/New_York
  - stable release of changes from 1.300017
  1.300017  2015-05-14 13:17:39-04:00 America/New_York (TRIAL RELEASE)
  - cope with a double-encoding but in Net::SMTP
    for details, https://rt.cpan.org/Ticket/Display.html?id=104433
* Wed Apr 15 2015 coolo@suse.com
- updated to 1.300016
  see /usr/share/doc/packages/perl-Email-Sender/Changes
  1.300016  2014-10-10 22:54:00-04:00 America/New_York
  - no changes since 1.300015, just made non-trial release
  1.300015  2014-09-12 22:01:37-04:00 America/New_York (TRIAL RELEASE)
    [THIS MIGHT BREAK YOUR CODE]
  - version 1.300008 was meant to rewrite line endings when sending to
    sendmail, but the change was not effective; it has been fixed
  1.300014  2014-08-28 14:21:26-04:00 America/New_York
  - do not try passing an empty string as a Failure message
  1.300013  2014-08-28 11:00:16-04:00 America/New_York
  - sometimes, if no error is given and $smtp->message returns (),
    the arguments to the Failure constructor were out of alignment and
    the failure's error message would be "code"; this has been fixed
  1.300012  2014-07-10 09:55:35-04:00 America/New_York
  - documentation fix: there's no Email::MIME->delete_header
    (thanks, Kris Matthews)
  1.300011  2014-03-02 18:16:12-05:00 America/New_York
  - run the sendmail program with -i by default (thanks, William Blunn)
  - do not die when a race causes mkpath(Maildir/new) to fail because the
    directory already exists
  1.300010  2014-01-11 14:15:13-05:00 America/New_York
  - the SMTP transport now has a "debug" option
  1.300009  2013-09-01 12:03:06 America/New_York
    see also 1.300008!
    switch to automatic determination of prereqs to improve accuracy
  1.300008  2013-09-01 09:39:13 America/New_York
    [THIS MIGHT BREAK YOUR CODE]
    at long last, Sendmail and Maildir transports replaces CRLF with CR
    before piping
    [BUG FIXES]
    fixes a bug where recipients beginning with a - would not work with
    the Sendmail transport [rt.perl.org #66246]
    require Email-Abstract 3.006, to get Email-Simple 1.998, to get
    Email::Simple->new(\$str), resolving [rt.perl.org #85926]
  1.300007  2013-03-19 14:58:27 America/New_York
    when sending over SMTP, send DATA in hunks of 1 mebibyte or smaller
  1.300006  2013-03-17 17:23:21 America/New_York
    re-fix the problem with attribute accessors and role methods
    clashing, previously fixed in 0.102360
  1.300005  2013-02-14 11:37:09 America/New_York
    add missing prereq, Sub::Exporter; thanks for report, Esteban
    Manchado Velázquez
  1.300004  2013-02-09 10:09:02 America/New_York
    bump required version of MooX::Types::MooseLike
  1.300003  2013-02-06 15:56:53 America/New_York
    make Wrapper transports proxy is_simple and allow_partial_success to
    the wrapped transport
    allow Wrapper transports to construct their own targets; useful for
    configuring entire wrapper chain from the environment
  1.300002  2013-02-06 14:06:24 America/New_York
    THIS IS A BIG DEAL:  see v1.300000
    this is the first non-trial release using Moo instead of Moose
    increase version of Moo to interoperate with ancient Mouse.pm
  1.300001  2013-01-07 21:38:31 America/New_York
    increase required versions of Throwable and Moo
  1.300000  2013-01-02 22:42:58 America/New_York
    THIS IS A BIG DEAL:
    use Moo instead of Moose (thanks to Justin Hunter and Christian
    Walde!)
  0.120002  2012-09-11 14:43:07 America/New_York
    added shift_deliveries to the Test transport, for treating the
    sent messages like a queue of things to inspect
  0.120001  2012-07-19 16:28:01 America/Los_Angeles
    no changes from 0.120000, just marked as stable release
  0.120000  2012-05-08 20:53:43 America/New_York
    THIS IS A BIG DEAL:
    This release deprecates the scalar context behavior of:
  * Failure->recipients
  * Failure::Multi->failures
  * Failure::Multi->recipients
  * Transport::Test->deliveries
  * Transport::Failable->failure_conditions
    Until now, these methods returned a list in list context and
    an array reference in scalar context.  This still works, but
    scalar context calls will now generate a warning.  In one
    year (2013-05), they will be become fatal.
  0.110005  2012-03-05 21:37:35 America/New_York
    binmode output handle to avoid line ending munging in Mbox and
    Maildir; thanks, Christian Walde!
  0.110004  2012-02-21 17:47:35 America/New_York
    import the "Bcc" page from the (otherwise empty) github wiki; this
    adds some information to the QuickStart page about why Bcc support
    isn't there and why this isn't a bug
  0.110003  2012-02-01 15:09:52 America/New_York
    add the add_lines_header and add_envelope_headers attributes to
    Maildir transports
  0.110002  2012-01-31 17:02:35 America/New_York
    Maildir deliveries now have a ->filename method to tell you just
    where the mail was delivered
* Tue Nov  1 2011 pascal.bleser@opensuse.org
- update to 0.110001: no user-visible changes
- added missing Requires: perl(Throwable)
- enabled tests
* Fri Mar 18 2011 pascal.bleser@opensuse.org
- update to 0.110000:
  * provide a much clearer and more fatal error when SASL authentication has
    failed because Authen::SASL or MIME::Base64 is not available
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Wed Aug 25 2010 pascal.bleser@opensuse.org
- update to 0.102370:
  * remove spurious prereq on Sys::Hostname::Long
  * tweak some tests for truth/definedness in SMTP transport
* Tue Aug 24 2010 pascal.bleser@opensuse.org
- update to 0.102360:
  * avoid the need to use "excludes" in role application; this silences
    warnings with Moose 1.10
* Fri Jun 25 2010 pascal.bleser@opensuse.org
- update to 0.101760:
  * fix sendmail.t with latest Capture::Tiny
* Sun Mar 14 2010 pascal.bleser@opensuse.org
- update to 0.100460:
  * allow timeout option to SMTP transport
  * Email::Sender::Failure is now a Throwable::Error
  * now uses Try::Tiny for internal exception handling
  * bump Moose prereq to 0.70
  * allow uppercase env vars to set transport attributes
  * add "message" attribute to successes returned by SMTP transports
  * improve reliability of t/sendmail.t
* Sat Dec  5 2009 pascal.bleser@opensuse.org
- update to 0.093380
* Mon Nov  9 2009 pascal.bleser@opensuse.org
- update to 0.093110:
  * allow uppercase env vars to set transport attributes (charsbar)
  * add "message" attribute to successes returned by SMTP transports
* Thu Oct 29 2009 pascal.bleser@opensuse.org
- initial package
